pub enum JwtValidationResult<T> {
Valid(JwtClaims<T>),
InvalidToken,
InvalidIssuer {
expected: String,
actual: String,
},
}Expand description
Result of validating a JWT token.
This type separates successful validation from the two expected failure categories exposed by this crate:
- the token could not be decoded or validated
- the token decoded successfully but did not match the expected issuer
Variants
Valid(JwtClaims<T>)
Token is valid and contains decoded claims.
InvalidToken
Token could not be decoded or failed JWT validation.
This includes malformed tokens and tokens rejected by the configured JWT validation settings.
InvalidIssuer
Token decoded successfully but has the wrong issuer.